provisioning_profiles_dir = File.join(Dir.home(Etc.getlogin), 'dev_portal', 'provisioning_profiles')
certificates_dir = File.join(Dir.home(Etc.getlogin), 'dev_portal', 'certificates')

directory provisioning_profiles_dir do
  recursive true
  action :create
end

directory certificates_dir do
  recursive true
  action :create
end

bag_name = 'apple_dev_portal'
data_bag(bag_name).each do |bag_item_name|
  apple_dev_metadata = Chef::EncryptedDataBagItem.load(bag_name, bag_item_name)
  username = apple_dev_metadata['username']
  password = apple_dev_metadata['password']

  execute "download provisioning profiles for #{bag_item_name}" do
    command "ios profiles:download:all --username '#{username}' --password '#{password}' --type distribution"
    cwd provisioning_profiles_dir
  end

  ## Currently unused in favor of pulling certificate and key from data bag. Six in one, half dozen in the other... as they say.
  # apple_dev_metadata['certificates'].each do |cert|
  #   execute "download certificate #{cert} for #{bag_item_name}" do
  #     command "ios certificates:download '#{cert}' --username '#{username}' --password '#{password}' --type distribution"
  #     cwd certificates_dir
  #   end
  # end

  provisioning_profiles_sys_path = "#{Dir.home(Etc.getlogin)}/Library/MobileDevice/Provisioning Profiles"

  bash "install provisioning profiles for #{bag_item_name}" do
    code <<-EOH
      rm -vRf "#{provisioning_profiles_sys_path}/*"
      mkdir -p "#{provisioning_profiles_sys_path}/*"
      cp -v "#{provisioning_profiles_dir}"/* "#{provisioning_profiles_sys_path}"
    EOH
  end

  node.default['teamcity']['agents']['default']['system_properties']['provisioning_profiles'][bag_item_name] = true

  # Extract cert from encrypted data bag.
  cert = certificate_manage bag_item_name do
    data_bag bag_name
    cert_path "#{certificates_dir}"
    cert_file "#{bag_item_name}.cer"
    key_file "#{bag_item_name}.key"
    owner Etc.getlogin
    group 'Staff'
  end

  execute "install certificate: #{bag_item_name}.cer" do
    command "security import '#{certificates_dir}/certs/#{bag_item_name}.cer' -x -k /Library/Keychains/System.keychain -T /usr/bin/codesign"
    returns [0,1]
  end

  execute "install private key: #{bag_item_name}.pem" do
    command "security import '#{certificates_dir}/private/#{bag_item_name}.key' -x -k /Library/Keychains/System.keychain -T /usr/bin/codesign"
    returns [0,1]
  end

  unless cert.nil?
    node.default['teamcity']['agents']['default']['system_properties']['certificates'][bag_item_name] = true
  end
end

directory provisioning_profiles_dir do
  recursive true
  action :delete
end

directory certificates_dir do
  recursive true
  action :delete
end
